
.authorizepmnt_payment_process{
  padding: 0 !important;
}
.authorizepmnt_payment_process_top{
  text-align:center !important;
}
.authorizepmnt_payment_process_top p{
  font-size:20px;
}

.authorizepmnt_payment_details_head{
  padding:10px 15px;
  font-weight:var(--theme-font-weight-bold) !important;
  font-size:17px;
  text-align: center;
  margin-block: 20px;
  background-color:var(--theme-button-background-color);
  color:var(--theme-button-font-color);
}
.authorizepmnt_payment_details_main > form  {
  border-radius: 0 !important;
  padding: 0 !important;
  box-shadow: none !important;
  border: 0 !important;
}
.authorizepmnt_payment_details_row{
  display:flex;
}
.authorizepmnt_payment_details_field{
  padding:10px;
  display:flex;
  flex-wrap:wrap;
  gap:10px;
  width:100%;
}
.authorizepmnt_payment_details_field label{
  font-size:var(--theme-font-size-small);
  margin:0;
  padding:0;
  width:100%;
}
.authorizepmnt_payment_details_field input{
  min-width:100%;
  max-width:100%;
  width:100%;
}
.authorizepmnt_payment_details_field > div{
  width:calc(50% - 5px);
}
.authorizepmnt_payment_details_field > button#authorize-pmt-btn {
  height: 45px;
  border-radius: 10px;
}