/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Authorizepmnt
 * @copyright  Copyright 2006-2025 Ahead WebSoft Technologies
 * @license    https://socialengine.com/eula
 * @version    $Id: my.sql 2025-01-22 00:00:00Z 
 * @author     SocialEngine
 */


INSERT IGNORE INTO `engine4_core_modules` (`name`, `title`, `description`, `version`, `enabled`, `type`) VALUES  ('authorizepmnt', 'Authorize.net Payment Gateway Plugin', 'Authorize.net Payment Gateway Plugin', '7.1.0', 1, 'extra') ;

INSERT IGNORE INTO `engine4_core_menuitems` (`name`, `module`, `label`, `plugin`, `params`, `menu`, `submenu`, `order`) VALUES
('core_admin_main_plugins_authorizepmnt', 'authorizepmnt', 'Authorize.net Payment Gateway Plugin', '', '{"route":"admin_default","module":"authorizepmnt","controller":"settings"}', 'core_admin_main_plugins', '', 999),

('authorizepmnt_admin_main_settings', 'authorizepmnt', 'Global Settings', '', '{"route":"admin_default","module":"authorizepmnt","controller":"settings"}', 'authorizepmnt_admin_main', '', 1);
