<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/

class Authorizepmnt_Bootstrap extends Engine_Application_Bootstrap_Abstract
{
	protected function _initFrontController()
	{
		include APPLICATION_PATH . '/application/modules/Authorizepmnt/controllers/Checklicense.php';
	}
}