UPDATE `engine4_core_menuitems` SET `module` = 'authorizepmnt', `params` = '{"route":"admin_default","module":"authorizepmnt","controller":"settings"}' WHERE `engine4_core_menuitems`.`name` = 'authorizepmnt_admin_main_settings';

UPDATE `engine4_payment_gateways` SET `plugin` = 'Payment_Plugin_Gateway_Authorize' WHERE `engine4_payment_gateways`.`plugin` = 'Authorizepmnt_Plugin_Gateway_Wallet_Authorize';